==> huaweicloudsdkecs-3.0.2b0-py3-none-any.whl: huaweicloudsdkecs/v2/model/nova_security_group_common_group.py <==
# coding: utf-8

import pprint
import re

import six


class NovaSecurityGroupCommonGroup(object):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    openapi_types = {
        'name': 'str',
        'tenant_id': 'str'
    }

    attribute_map = {
        'name': 'name',
        'tenant_id': 'tenant_id'
    }

    def __init__(self, name=None, tenant_id=None):  # noqa: E501
        """NovaSecurityGroupCommonGroup - a model defined in huaweicloud sdk"""

        self._name = None
        self._tenant_id = None
        self.discriminator = None

        self.name = name
        self.tenant_id = tenant_id

    @property
    def name(self):
        """Gets the name of this NovaSecurityGroupCommonGroup.

        对端安全组的名称

        :return: The name of this NovaSecurityGroupCommonGroup.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this NovaSecurityGroupCommonGroup.

        对端安全组的名称

        :param name: The name of this NovaSecurityGroupCommonGroup.
        :type: str
        """
        self._name = name

    @property
    def tenant_id(self):
        """Gets the tenant_id of this NovaSecurityGroupCommonGroup.

        对端安全组所属租户的租户ID

        :return: The tenant_id of this NovaSecurityGroupCommonGroup.
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this NovaSecurityGroupCommonGroup.

        对端安全组所属租户的租户ID

        :param tenant_id: The tenant_id of this NovaSecurityGroupCommonGroup.
        :type: str
        """
        self._tenant_id = tenant_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NovaSecurityGroupCommonGroup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkecs-3.0.23b0-py3-none-any.whl: huaweicloudsdkecs/v2/model/nova_security_group_common_group.py <==
# coding: utf-8

import pprint
import re

import six





class NovaSecurityGroupCommonGroup:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'tenant_id': 'str'
    }

    attribute_map = {
        'name': 'name',
        'tenant_id': 'tenant_id'
    }

    def __init__(self, name=None, tenant_id=None):
        """NovaSecurityGroupCommonGroup - a model defined in huaweicloud sdk"""
        
        

        self._name = None
        self._tenant_id = None
        self.discriminator = None

        self.name = name
        self.tenant_id = tenant_id

    @property
    def name(self):
        """Gets the name of this NovaSecurityGroupCommonGroup.

        对端安全组的名称

        :return: The name of this NovaSecurityGroupCommonGroup.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this NovaSecurityGroupCommonGroup.

        对端安全组的名称

        :param name: The name of this NovaSecurityGroupCommonGroup.
        :type: str
        """
        self._name = name

    @property
    def tenant_id(self):
        """Gets the tenant_id of this NovaSecurityGroupCommonGroup.

        对端安全组所属租户的租户ID

        :return: The tenant_id of this NovaSecurityGroupCommonGroup.
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this NovaSecurityGroupCommonGroup.

        对端安全组所属租户的租户ID

        :param tenant_id: The tenant_id of this NovaSecurityGroupCommonGroup.
        :type: str
        """
        self._tenant_id = tenant_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NovaSecurityGroupCommonGroup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
